pub enum Resolution {
ActivityCompleted(Payload),
ActivityFailedTerminal(ActivityError),
TimerFired,
TimerStarted,
SignalDelivered(Payload),
TimerCancelled,
WithTimeout {
outcome: WithTimeoutOutcome,
result: Option<Payload>,
},
SignalSent,
ChildStarted(WorkflowId),
ChildCompleted(Payload),
ChildFailed(WorkflowError),
}Expand description
Recorded outcome produced by resolving a command against history.
Variants
ActivityCompleted(Payload)
A recorded activity completion with its result payload.
ActivityFailedTerminal(ActivityError)
A recorded terminal activity failure.
TimerFired
A recorded timer firing.
TimerStarted
A recorded timer start without a terminal timer outcome yet.
SignalDelivered(Payload)
A recorded signal delivery with its payload.
TimerCancelled
A recorded timer cancellation.
WithTimeout
A recorded with_timeout terminal outcome with an optional result payload.
Fields

outcome: WithTimeoutOutcomeRecorded timeout outcome.
SignalSent
A recorded successful signal send.
ChildStarted(WorkflowId)
A recorded child workflow start with its child identifier.
ChildCompleted(Payload)
A recorded child workflow completion with its result payload.
ChildFailed(WorkflowError)
A recorded child workflow failure.