pub struct FoundEventDescriptor {
pub seq: u64,
pub family: Option<RecordedEventFamily>,
pub key: Option<CorrelationKey>,
pub kind: &'static str,
}Expand description
Data describing the recorded event found at the cursor’s current position.
Fields
seq: u64Sequence number of the recorded event.
family: Option<RecordedEventFamily>Replay family for the recorded event, if it is matchable by the cursor.
key: Option<CorrelationKey>Correlation key derived for the recorded event, if it starts a matchable command.
kind: &'static strStable event-variant name for diagnostics.