pub enum LiveActivityOutcome {
Completed(Payload),
Failed(ActivityError),
}Expand description
Live outcome produced by AE after running an activity for real.
Variants
Completed(Payload)
The activity completed successfully with an opaque result payload.
Failed(ActivityError)
The activity reached its terminal failure state after live retry policy was exhausted.