WorkflowMailboxMessage

Enum WorkflowMailboxMessage 

pub enum WorkflowMailboxMessage {
    TimerFired {
        timer_id: TimerId,
        fire_at: DateTime<Utc>,
    },
    SignalReceived {
        name: String,
        payload: Payload,
    },
    Query {
        name: String,
        payload: Payload,
        reply_to: QueryReplySender,
    },
    ChildWorkflowCompleted {
        child_workflow_id: WorkflowId,
        correlation: u64,
        result: Payload,
    },
    ChildWorkflowFailed {
        child_workflow_id: WorkflowId,
        correlation: u64,
        error: WorkflowError,
    },
    ChildWorkflowCancelled {
        child_workflow_id: WorkflowId,
        correlation: u64,
    },
}
Message kinds AT may ask AE to deliver to a workflow process mailbox.

Variants



TimerFired

A durable timer fired and has been recorded.

Fields

timer_id: TimerId

Timer that fired.

fire_at: DateTime<Utc>

Deterministic fire timestamp carried for service/replay correlation.



SignalReceived

A durable signal arrived and has been recorded.

Fields

name: String

Signal name selected by the sender.

payload: Payload

Opaque signal payload.



Query

A read-only query request. Query dispatch records no event.

Fields

name: String

Query name selected by the caller.

payload: Payload

Opaque query input payload.

reply_to: QueryReplySender

One-shot channel for the workflow query handler’s reply.



ChildWorkflowCompleted

A linked child workflow completed successfully and has been recorded.

Fields

child_workflow_id: WorkflowId

Child workflow that produced the result.

correlation: u64

Spawn correlation token used by collectors.

result: Payload

Opaque child result payload.



ChildWorkflowFailed

A linked child workflow failed terminally and has been recorded.

Fields

child_workflow_id: WorkflowId

Child workflow that failed.

correlation: u64

Spawn correlation token used by collectors.

error: WorkflowError

Terminal child workflow failure.



ChildWorkflowCancelled

A linked child workflow was cancelled and has been recorded.

Fields

child_workflow_id: WorkflowId

Child workflow that was cancelled.

correlation: u64

Spawn correlation token used by collectors.