pub type QueryResult = Result<Payload, QueryError>;Expand description
Result sent by workflow query handlers over a query reply channel.
Aliased Type
pub enum QueryResult {
Ok(Payload),
Err(QueryError),
}pub type QueryResult = Result<Payload, QueryError>;Result sent by workflow query handlers over a query reply channel.
pub enum QueryResult {
Ok(Payload),
Err(QueryError),
}