pub struct WorkflowNode { /* private fields */ }Expand description
Snapshot of a workflow process and its linked activity children.
Implementations
Sourceimpl WorkflowNode
impl WorkflowNode
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
Logical workflow type for this process.
Sourcepub fn workflow_pid(&self) -> Pid
pub fn workflow_pid(&self) -> Pid
Workflow process PID.
Sourcepub fn activity_children(&self) -> &BTreeSet<Pid>
pub fn activity_children(&self) -> &BTreeSet<Pid>
Activity child PIDs one level below this workflow process.
Sourcepub fn has_activity_child(&self, activity_pid: Pid) -> bool
pub fn has_activity_child(&self, activity_pid: Pid) -> bool
Returns true when the activity is recorded as a linked child of this workflow.