pub fn surface_activity_error(
runtime: &RuntimeHandle,
parent_pid: Pid,
activity_pid: Pid,
error: ActivityError,
) -> Result<(), EngineError>Expand description
Attach a typed activity error to a trapped activity EXIT signal.
This helper is used by the runtime/AT seam when an activity implementation
has produced a classified ActivityError before the linked process exits.
Errors
Returns EngineError::Runtime when the workflow process is no longer live.