pub enum EngineSeamError {
NonResident {
workflow_id: WorkflowId,
},
Terminal {
workflow_id: WorkflowId,
},
UnknownWorkflow {
workflow_id: WorkflowId,
},
Delivery {
reason: String,
},
ChildSpawn {
reason: String,
},
TimerWheel {
reason: String,
},
ChildTermination {
reason: String,
},
Recorder {
reason: String,
},
}Expand description
Errors returned by the engine seam.
Variants
NonResident
The target workflow has no current live process.
Fields

workflow_id: WorkflowIdWorkflow that had no current live process.
Terminal
The target workflow is terminal.
Fields

workflow_id: WorkflowIdTerminal workflow identifier.
UnknownWorkflow
The target workflow is unknown to AE.
Fields

workflow_id: WorkflowIdUnknown workflow identifier.
Delivery
AE could not deliver a mailbox message.
ChildSpawn
AE could not spawn a linked child workflow.
TimerWheel
AE could not arm or disarm the timer wheel.
ChildTermination
AE could not terminate a linked child process.
Recorder
AD’s single Recorder path could not record the event.