pub enum WorkflowMailboxMessage {
TimerFired {
timer_id: TimerId,
fire_at: DateTime<Utc>,
},
SignalReceived {
name: String,
payload: Payload,
},
Query {
name: String,
payload: Payload,
reply_to: QueryReplySender,
},
ChildWorkflowCompleted {
child_workflow_id: WorkflowId,
correlation: u64,
result: Payload,
},
ChildWorkflowFailed {
child_workflow_id: WorkflowId,
correlation: u64,
error: WorkflowError,
},
ChildWorkflowCancelled {
child_workflow_id: WorkflowId,
correlation: u64,
},
}Expand description
Message kinds AT may ask AE to deliver to a workflow process mailbox.
Variants
TimerFired
A durable timer fired and has been recorded.
Fields
SignalReceived
A durable signal arrived and has been recorded.
Query
A read-only query request. Query dispatch records no event.
Fields

reply_to: QueryReplySenderOne-shot channel for the workflow query handler’s reply.
ChildWorkflowCompleted
A linked child workflow completed successfully and has been recorded.
Fields

child_workflow_id: WorkflowIdChild workflow that produced the result.
ChildWorkflowFailed
A linked child workflow failed terminally and has been recorded.
Fields

child_workflow_id: WorkflowIdChild workflow that failed.

error: WorkflowErrorTerminal child workflow failure.
ChildWorkflowCancelled
A linked child workflow was cancelled and has been recorded.
Fields

child_workflow_id: WorkflowIdChild workflow that was cancelled.